## dbt-adapters 1.14.3 - March 19, 2025

### Features

- Add Base Adapter implementation of Catalog Integration support. ([#790](https://github.com/dbt-labs/dbt-adapters/issues/790))

### Fixes

- Run python models normally instead of breaking when run with `--sample` or `--empty` ([#906](https://github.com/dbt-labs/dbt-adapters/issues/906))

### Under the Hood

- Add node_checksum to NodeInfo in structured logs ([#883](https://github.com/dbt-labs/dbt-adapters/issues/883))
- Make use of new record/replay features to enable recording "available" functions ([#761](https://github.com/dbt-labs/dbt-adapters/issues/761))
